import Script from 'next/script';
import React from 'react';
import { GoogleTagManagerClient } from './Client';

const GTM_ID = process.env.NEXT_PUBLIC_GTM_ID;
/**
 * Prepare the dataLayer without loading gtm.js
 *
 * This is a React Element, not a component, see example.
 *
 * @example
 * <head>{GoogleTagManagerHead}</head>
 */ const GoogleTagManagerHead = GTM_ID ? /*#__PURE__*/ React.createElement("script", {
    id: "gtm-head",
    dangerouslySetInnerHTML: {
        __html: `window.dataLayer=window.dataLayer||[{'gtm.start':new Date().getTime(),event:'gtm.js'}];`
    }
}) : null;
/**
 * Load gtm.js after page is interactive
 *
 * @example
 * <body>
 *   {children}
 *   {GoogleTagManagerBody}
 * </body>
 */ const GoogleTagManagerBody = GTM_ID ? /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(GoogleTagManagerClient, null), /*#__PURE__*/ React.createElement(Script, {
    src: `//www.googletagmanager.com/gtm.js?id=${GTM_ID}`,
    async: true,
    defer: true,
    id: "gtm-body",
    strategy: "afterInteractive"
}), /*#__PURE__*/ React.createElement("noscript", null, /*#__PURE__*/ React.createElement("iframe", {
    src: `//www.googletagmanager.com/ns.html?id=${GTM_ID}`,
    height: "0",
    width: "0",
    style: {
        display: 'none',
        visibility: 'hidden'
    }
}))) : /*#__PURE__*/ React.createElement(GoogleTagManagerClient, null);

export { GTM_ID, GoogleTagManagerBody, GoogleTagManagerHead };
