import IntlMessageFormat from 'intl-messageformat';
import { ReactElement, ReactNodeArray } from 'react';
import AbstractIntlMessages from './AbstractIntlMessages';
import Formats from './Formats';
import { InitializedIntlConfig } from './IntlConfig';
import IntlError from './IntlError';
import TranslationValues, { RichTranslationValues } from './TranslationValues';
import MessageKeys from './utils/MessageKeys';
import NestedKeyOf from './utils/NestedKeyOf';
import NestedValueOf from './utils/NestedValueOf';
export declare function getMessagesOrError<Messages extends AbstractIntlMessages>({ messages, namespace, onError }: {
    messages: Messages;
    namespace?: string;
    onError?(error: IntlError): void;
}): AbstractIntlMessages | IntlError;
export type CreateBaseTranslatorProps<Messages> = InitializedIntlConfig & {
    cachedFormatsByLocale?: Record<string, Record<string, IntlMessageFormat>>;
    defaultTranslationValues?: RichTranslationValues;
    namespace?: string;
    messagesOrError: Messages | IntlError;
};
export default function createBaseTranslator<Messages extends AbstractIntlMessages, NestedKey extends NestedKeyOf<Messages>>({ cachedFormatsByLocale, defaultTranslationValues, formats: globalFormats, getMessageFallback, locale, messagesOrError, namespace, onError, timeZone }: CreateBaseTranslatorProps<Messages>): {
    <TargetKey extends MessageKeys<NestedValueOf<Messages, NestedKey>, NestedKeyOf<NestedValueOf<Messages, NestedKey>>>>(key: TargetKey, values?: TranslationValues, formats?: Partial<Formats>): string;
    rich: (key: string, values?: RichTranslationValues, formats?: Partial<Formats>) => string | ReactElement | ReactNodeArray;
    raw(key: string): any;
};
